@@ -1,8 +1,8 @@
-from typing import Optional
 from pathlib import Path
+from typing import Optional
 
-from .base import BaseProcessor
-from ..exceptions import TDSValueError
+from textdatasetcleaner.exceptions import TDCValueError
+from textdatasetcleaner.processors.base import BaseProcessor
 
 
 class LineConvertCaseProcessor(BaseProcessor):
@@ -13,10 +13,8 @@ class LineConvertCaseProcessor(BaseProcessor):
     def __init__(self, mode: str):
         allowed = ['title', 'lower', 'upper']
         if mode not in allowed:
-            raise TDSValueError(f'Wrong mode for {self.name} processor: {mode}, allowed only: {allowed}')
+            raise TDCValueError(f'Wrong mode for {self.name} processor: {mode}, allowed only: {allowed}')
         self.mode = mode
 
     def process_line(self, line: str) -> Optional[str]:
-        line = getattr(line, self.mode)()
-
-        return line
+        return getattr(line, self.mode)()
